<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="productOutTemplateTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></table-form>
    </basic-container>
  </div>
</template>
<script>
  import {fetchList,delObj,updateStatus} from '@/api/product/productouttemplate';
  import {remote} from '@/api/admin/dict';
  import ttable from '@/views/common/ztt-table.vue';
  import TableForm from './productouttemplate-form'
  export default {
    data () {
      return {
        ajaxFun:fetchList,
        dataListLoading: false,
        multipleSelection: [],
        isShowQuery:false,
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        dateTimeFilters:{},
        prelang:"productouttemplate",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:true,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'createTime',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //模板编号
            {minWidth:'140',prop:"templateNo",label:"模板编号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',render:{fun:this.addOrUpdateHandle}},
            //模板描述
            {minWidth:'140',prop:"testDesc",label:"模板描述",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //报工类型
            {minWidth:'120',prop: "testType",label:"报工类型",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',optList:() => {return this.getTestTypeList()},formatter: (row, column, cellValue) => {return this.formatTestType(cellValue)}},
            //编制时间
            {minWidth:'120',prop: "createTime",label:"编制时间",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange'},
            //编制人
            {minWidth:'140',prop:"createUser",label:"编制人",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //启用状态
            {minWidth:'120',prop: "status",label:"启用状态",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',optList:() => {return this.getStatusList()},formatter: (row, column, cellValue) => {var formatVal;if(cellValue){formatVal='启用';}else{formatVal='未启用';} return formatVal;}}
          ],
          toolbar: [
            {
              text: '新增',
              type: 'primary',
              fun: this.addOrUpdateHandle,
              disabled:false,
              permitArr:[]
            },
            {
              text: '启用',
              fun:()=> {this.approveHandle(true);},
              disabled:false,
              permitArr:[]
            },
            {
              text: '关闭',
              fun:()=> {this.approveHandle(false);},
              disabled:false,
              permitArr:[]
            }
          ],
          operator:[
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:100,
            minWidth:100
          },
        },
        addOrUpdateVisible: false,
        testTypeList:[],
        statusList:[
          {value:true,label:'启用'},
          {value:false,label:'未启用'}
        ]
      }
    },
    components: {
      ttable,
      TableForm
    },
    created () {
      this.initTestTypeList();
    },
    methods:{
      //获取报工类型
      initTestTypeList(){
        remote('work_type').then(response => {
          var typeList = response.data.data;
          this.testTypeList=[];
          if(typeList!=null && typeList.length>0){
            var testType;
            for(var i=0;i<typeList.length;i++){
              testType={};
              testType.value=typeList[i].value;
              testType.label=typeList[i].label;
              this.testTypeList.push(testType);
            }
          }
        })
      },
      // 获取数据列表
      getData () {
        this.$refs.productOutTemplateTable.getDataList();
      },
      // 新增 / 修改
      addOrUpdateHandle (row) {
        this.addOrUpdateVisible = true;
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row==null?null:row.id);
        })
      },
      // 删除
      deleteHandle (row) {
        this.$confirm('是否确认删除ID为' + row.id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(response => {
          var data=response.data;
          if(data.code==0){
            this.$message.success('删除成功');
          }else{
            this.$message.error('删除失败');
          }
          this.getData();
        })
      },
      handleSelectionChange(val){
        this.multipleSelection = val
      },
      //启用或关闭
      approveHandle(event){
        var eventName;
        if(event){
          eventName='启用';
        }else{
          eventName='关闭';
        }

        if(this.multipleSelection.length>0) {
          var statusForm={id:this.multipleSelection[0].id,status:event};
          updateStatus(statusForm).then(response => {
            var data = response.data;
            if (data.code == 0) {
              this.$message.success(eventName+'成功');
              this.getData();
            } else {
              this.$message.error(eventName+'失败');
            }
          });
        }else{
          this.$message.error('请选择'+eventName+'的对象');
        }
      },
      getTestTypeList(){
        return this.testTypeList;
      },
      formatTestType(val){
        var testType = this.testTypeList.find(item=>item.value===val)
        return testType.label;
      },
      getStatusList(){
        return this.statusList;
      }

    }
  }
</script>
